@@ -1,7 +1,7 @@
 #!/bin/sh
 
-for x in */*/*.xml; do
+for x in */C/*.xml; do
 		y=$(basename ${x})
 		echo ${y}
-		../validate.sh */*/${y}
+		../validate.sh */C/${y}
 done
